#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-casing
version:              0.2.0.0
visibility:           public
id:                   aeson-casing-0.2.0.0-KnpkTYi2I5zKYdolEx9Sup
key:                  aeson-casing-0.2.0.0-KnpkTYi2I5zKYdolEx9Sup
license:              MIT
maintainer:           andrewrademacher@gmail.com
author:               Andrew Rademacher
synopsis:
    Tools to change the formatting of field names in Aeson
    instances.

description:
    Tools to change the formatting of field names in Aeson
    instances. This includes CamelCasing, Pascal Casing and
    Snake Casing.

category:             Data
abi:                  437471b6c9debe5d9dd210eb9138de05
exposed:              True
exposed-modules:      Data.Aeson.Casing Data.Aeson.Casing.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-casing-0.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-casing-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-casing-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-casing
hs-libraries:         HSaeson-casing-0.2.0.0-KnpkTYi2I5zKYdolEx9Sup
depends:              aeson-2.2.2.0-6c1DCPq2cjw7mSOIGM724W base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-aeson-casing/html/aeson-casing.haddock

haddock-html:         /usr/share/doc/haskell-aeson-casing/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

